SWDEV-339657 - Update catch codes with correct coordinates (#2735)
Change-Id: I8ca78d770a742bf6c2abede494759caa923fcc19
[ROCm/hip commit: 0cf0ead620]
Este cometimento está contido em:
cometido por
GitHub
ascendente
314d6ed916
cometimento
998c7a62a0
@@ -57,7 +57,7 @@ Testcase Scenarios :
|
||||
* Kernel Functions to copy.
|
||||
*/
|
||||
static __global__ void copy_ker_func(int* a, int* b) {
|
||||
int tx = hipBlockIdx_x*hipBlockDim_x + hipThreadIdx_x;
|
||||
int tx = blockIdx.x*blockDim.x + threadIdx.x;
|
||||
if (tx < LEN) b[tx] = a[tx];
|
||||
}
|
||||
|
||||
|
||||
Criar uma nova questão referindo esta
Bloquear um utilizador